**Example 1: 释放IPV6转换实例**

释放IPV6转换实例

Input: 

```
tccli vpc DeleteIp6Translators --cli-unfold-argument  \
    --Ip6TranslatorIds ip6-90pt7p9q
```

Output: 
```
{
    "Response": {
        "RequestId": "65c729e7-9f5f-4441-b1d2-1a6db100af9e"
    }
}
```

